# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/jplan.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/jplan.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n machinetalk/protobuf/jplan.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\"W\n\nJplanJoint\x12\x0f\n\x07pos_cmd\x18\x01 \x01(\x01\x12\x0f\n\x07max_vel\x18\x02 \x01(\x01\x12\x0f\n\x07max_acc\x18\x03 \x01(\x01\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08:\x06\x92?\x03H\xe0\x02\"E\n\x0cJplanCommand\x12-\n\x05joint\x18\x02 \x03(\x0b\x32\x17.machinetalk.JplanJointB\x05\x92?\x02\x10\n:\x06\x92?\x03H\xe2\x02')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_JPLANJOINT = _descriptor.Descriptor(
  name='JplanJoint',
  full_name='machinetalk.JplanJoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pos_cmd', full_name='machinetalk.JplanJoint.pos_cmd', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_vel', full_name='machinetalk.JplanJoint.max_vel', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_acc', full_name='machinetalk.JplanJoint.max_acc', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enable', full_name='machinetalk.JplanJoint.enable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\340\002')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=171,
)


_JPLANCOMMAND = _descriptor.Descriptor(
  name='JplanCommand',
  full_name='machinetalk.JplanCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint', full_name='machinetalk.JplanCommand.joint', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\020\n'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\342\002')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=242,
)

_JPLANCOMMAND.fields_by_name['joint'].message_type = _JPLANJOINT
DESCRIPTOR.message_types_by_name['JplanJoint'] = _JPLANJOINT
DESCRIPTOR.message_types_by_name['JplanCommand'] = _JPLANCOMMAND

JplanJoint = _reflection.GeneratedProtocolMessageType('JplanJoint', (_message.Message,), dict(
  DESCRIPTOR = _JPLANJOINT,
  __module__ = 'machinetalk.protobuf.jplan_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.JplanJoint)
  ))
_sym_db.RegisterMessage(JplanJoint)

JplanCommand = _reflection.GeneratedProtocolMessageType('JplanCommand', (_message.Message,), dict(
  DESCRIPTOR = _JPLANCOMMAND,
  __module__ = 'machinetalk.protobuf.jplan_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.JplanCommand)
  ))
_sym_db.RegisterMessage(JplanCommand)


_JPLANJOINT.has_options = True
_JPLANJOINT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\340\002'))
_JPLANCOMMAND.fields_by_name['joint'].has_options = True
_JPLANCOMMAND.fields_by_name['joint']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\020\n'))
_JPLANCOMMAND.has_options = True
_JPLANCOMMAND._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\342\002'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/rtapicommand.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/rtapicommand.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n\'machinetalk/protobuf/rtapicommand.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\"\xf7\x01\n\x0cRTAPICommand\x12\x10\n\x08instance\x18\x01 \x02(\x05\x12\x0f\n\x07modname\x18\x02 \x01(\t\x12\x13\n\x0brt_msglevel\x18\x03 \x01(\x05\x12\x15\n\ruser_msglevel\x18\x04 \x01(\x05\x12\x0c\n\x04\x61rgv\x18\x05 \x03(\t\x12\x12\n\nthreadname\x18\x06 \x01(\t\x12\x14\n\x0cthreadperiod\x18\x07 \x01(\x05\x12\x0e\n\x06use_fp\x18\x08 \x01(\x08\x12\x0b\n\x03\x63pu\x18\t \x01(\x05\x12\x0c\n\x04\x63omp\x18\n \x01(\t\x12\x0c\n\x04\x66unc\x18\x0b \x01(\t\x12\x10\n\x08instname\x18\x0c \x01(\t\x12\r\n\x05\x66lags\x18\r \x01(\x05:\x06\x92?\x03H\x84\x07')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_RTAPICOMMAND = _descriptor.Descriptor(
  name='RTAPICommand',
  full_name='machinetalk.RTAPICommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='machinetalk.RTAPICommand.instance', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modname', full_name='machinetalk.RTAPICommand.modname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rt_msglevel', full_name='machinetalk.RTAPICommand.rt_msglevel', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_msglevel', full_name='machinetalk.RTAPICommand.user_msglevel', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='argv', full_name='machinetalk.RTAPICommand.argv', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='threadname', full_name='machinetalk.RTAPICommand.threadname', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='threadperiod', full_name='machinetalk.RTAPICommand.threadperiod', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_fp', full_name='machinetalk.RTAPICommand.use_fp', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='machinetalk.RTAPICommand.cpu', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comp', full_name='machinetalk.RTAPICommand.comp', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='func', full_name='machinetalk.RTAPICommand.func', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instname', full_name='machinetalk.RTAPICommand.instname', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='machinetalk.RTAPICommand.flags', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\204\007')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=339,
)

DESCRIPTOR.message_types_by_name['RTAPICommand'] = _RTAPICOMMAND

RTAPICommand = _reflection.GeneratedProtocolMessageType('RTAPICommand', (_message.Message,), dict(
  DESCRIPTOR = _RTAPICOMMAND,
  __module__ = 'machinetalk.protobuf.rtapicommand_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.RTAPICommand)
  ))
_sym_db.RegisterMessage(RTAPICommand)


_RTAPICOMMAND.has_options = True
_RTAPICOMMAND._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\204\007'))
# @@protoc_insertion_point(module_scope)
